@@ -39,15 +39,11 @@ import java.util.List;
 import java.util.Map;
 import java.util.concurrent.Future;
 import java.util.logging.Level;
-import java.util.stream.Collectors;
 
 import javax.net.ssl.HostnameVerifier;
 import javax.net.ssl.KeyManager;
-import javax.net.ssl.SNIHostName;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLEngine;
-import javax.net.ssl.SSLException;
-import javax.net.ssl.SSLParameters;
 import javax.net.ssl.SSLSession;
 import javax.net.ssl.TrustManager;
 
@@ -81,19 +77,16 @@ import org.apache.hc.client5.http.config.RequestConfig;
 import org.apache.hc.client5.http.impl.async.CloseableHttpAsyncClient;
 import org.apache.hc.client5.http.impl.auth.BasicCredentialsProvider;
 import org.apache.hc.client5.http.protocol.HttpClientContext;
+import org.apache.hc.client5.http.ssl.DefaultClientTlsStrategy;
 import org.apache.hc.core5.concurrent.BasicFuture;
 import org.apache.hc.core5.concurrent.FutureCallback;
 import org.apache.hc.core5.http.Header;
 import org.apache.hc.core5.http.HttpHost;
 import org.apache.hc.core5.http.HttpResponse;
 import org.apache.hc.core5.http.config.Registry;
-import org.apache.hc.core5.http.nio.ssl.BasicClientTlsStrategy;
 import org.apache.hc.core5.http.nio.ssl.TlsStrategy;
 import org.apache.hc.core5.http.protocol.HttpContext;
-import org.apache.hc.core5.net.NamedEndpoint;
-import org.apache.hc.core5.reactor.ssl.SSLSessionInitializer;
-import org.apache.hc.core5.reactor.ssl.SSLSessionVerifier;
-import org.apache.hc.core5.reactor.ssl.TlsDetails;
+import org.apache.hc.core5.reactor.ssl.SSLBufferMode;
 import org.apache.hc.core5.util.Timeout;
 
 /**
@@ -574,28 +567,21 @@ public class AsyncHTTPConduit extends HttpClientHTTPConduit {
                     final HostnameVerifier verifier = org.apache.cxf.transport.https.SSLUtils
                         .getHostnameVerifier(tlsClientParameters);
      
-                    tlsStrategy = new BasicClientTlsStrategy(sslcontext,
-                        new SSLSessionInitializer() {
-                            @Override
-                            public void initialize(NamedEndpoint endpoint, SSLEngine engine) {
-                                initializeSSLEngine(sslcontext, engine);
-                            }
-                        },
-                        new SSLSessionVerifier() {
-                            @Override
-                            public TlsDetails verify(NamedEndpoint endpoint, SSLEngine engine) 
-                                    throws SSLException {
-                                final SSLSession sslsession = engine.getSession();
+                    String[] cipherSuites =
+                        SSLUtils.getCiphersuitesToInclude(tlsClientParameters.getCipherSuites(),
+                                                          tlsClientParameters.getCipherSuitesFilter(),
+                                                          sslcontext.getSocketFactory().getDefaultCipherSuites(),
+                                                          SSLUtils.getSupportedCipherSuites(sslcontext),
+                                                          LOG);
+                    
+                    final String protocol = tlsClientParameters.getSecureSocketProtocol() != null ? tlsClientParameters
+                        .getSecureSocketProtocol() : sslcontext.getProtocol();
 
-                                if (!verifier.verify(endpoint.getHostName(), sslsession)) {
-                                    throw new SSLException("Could not verify host " + endpoint.getHostName());
-                                }
+                    final String[] protocols = findProtocols(protocol,
+                        sslContext.getSupportedSSLParameters().getProtocols());
 
-                                setSSLSession(sslsession);
-                                return new TlsDetails(sslsession, engine.getApplicationProtocol());
-                            }
-                        }
-                    );
+                    tlsStrategy = new DefaultClientTlsStrategy(sslcontext, protocols,
+                        cipherSuites, SSLBufferMode.STATIC, verifier);
                 } catch (final GeneralSecurityException e) {
                     LOG.warning(e.getMessage());
                 }
@@ -996,13 +982,6 @@ public class AsyncHTTPConduit extends HttpClientHTTPConduit {
         if (p != null) {
             sslengine.setEnabledProtocols(p);
         }
-
-        final List<String> serverNames = tlsClientParameters.getServerNames();
-        if (serverNames != null && !serverNames.isEmpty()) {
-            final SSLParameters params = new SSLParameters();
-            params.setServerNames(serverNames.stream().map(SNIHostName::new).collect(Collectors.toList()));
-            sslengine.setSSLParameters(params);
-        }
     }
     
     @Override
