@@ -32,13 +32,13 @@ import java.util.Map;
 import java.util.Set;
 import java.util.TreeMap;
 
-import javax.servlet.ServletInputStream;
-import javax.servlet.ServletOutputStream;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.xml.bind.JAXBElement;
 import javax.xml.namespace.QName;
 
+import jakarta.servlet.ServletInputStream;
+import jakarta.servlet.ServletOutputStream;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.xml.bind.JAXBElement;
 import org.apache.cxf.Bus;
 import org.apache.cxf.BusException;
 import org.apache.cxf.BusFactory;
@@ -710,9 +710,9 @@ public class UndertowHTTPDestinationTest {
                     when(response.getStatus()).thenReturn(status);
                     doNothing().when(response).flushBuffer();
                 }
-                when(request.getAttribute("javax.servlet.request.cipher_suite")).thenReturn("anythingwilldoreally");
+                when(request.getAttribute("jakarta.servlet.request.cipher_suite")).thenReturn("anythingwilldoreally");
                 when(request.getAttribute("javax.net.ssl.session")).thenReturn(null);
-                when(request.getAttribute("javax.servlet.request.X509Certificate")).thenReturn(null);
+                when(request.getAttribute("jakarta.servlet.request.X509Certificate")).thenReturn(null);
             }
         }
 
